package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// ImageFormat represents the image format information
type ImageFormat struct {
	Ext    string  `bson:"ext" json:"ext"`
	URL    string  `bson:"url" json:"url"`
	Hash   string  `bson:"hash" json:"hash"`
	Mime   string  `bson:"mime" json:"mime"`
	Name   string  `bson:"name" json:"name"`
	Path   *string `bson:"path" json:"path"`
	Size   float64 `bson:"size" json:"size"`
	Width  int     `bson:"width" json:"width"`
	Height int     `bson:"height" json:"height"`
}

// ImageFormats represents different sizes of image formats
type ImageFormats struct {
	Large     *ImageFormat `bson:"large,omitempty" json:"large,omitempty"`
	Small     *ImageFormat `bson:"small,omitempty" json:"small,omitempty"`
	Medium    *ImageFormat `bson:"medium,omitempty" json:"medium,omitempty"`
	Thumbnail *ImageFormat `bson:"thumbnail,omitempty" json:"thumbnail,omitempty"`
}

// ImageData represents the image data structure
type ImageData struct {
	ID         string       `bson:"id" json:"id"`
	Name       string       `bson:"name" json:"name"`
	Alt        string       `bson:"alternative_text" json:"alternativeText"`
	Caption    string       `bson:"caption" json:"caption"`
	Width      int          `bson:"width" json:"width"`
	Height     int          `bson:"height" json:"height"`
	Formats    ImageFormats `bson:"formats" json:"formats"`
	URL        string       `bson:"url" json:"url"`
	PreviewURL string       `bson:"preview_url" json:"previewUrl"`
}

// Image represents the image wrapper structure
type Image struct {
	Data ImageData `bson:"data" json:"data"`
}

// Material represents the material data model
type Material struct {
	Id          primitive.ObjectID `bson:"_id,omitempty" json:"id"`
	Name        string             `bson:"name" json:"name"`
	Desc        string             `bson:"desc" json:"desc"`
	Type        int                `bson:"type" json:"type"` // Material type (1: background, 2: container, etc.)
	Image       Image              `bson:"img" json:"img"`
	CreateTime  time.Time          `bson:"create_time" json:"createTime"`
	UpdateTime  time.Time          `bson:"update_time" json:"updateTime"`
	PublishTime time.Time          `bson:"publish_time" json:"publishTime"`
	Status      int                `bson:"status" json:"status"` // 0: disabled, 1: enabled
}
